# BCI2a, GIGA_Laplacian, databases
from .loaddb import GIGA, BCI2a, HighGamma, BCIilliteracy_MI, BCIilliteracy_ERP, BCIilliteracy_SSVEP

available_databases = 'GIGA BCI2a HighGamma BCIilliteracy_MI BCIilliteracy_ERP BCIilliteracy_SSVEP'.split()
